{% if widget.is_initial %}
    <p class="file-upload">
        {{ widget.initial_text }}:
        {% if widget.value %}
            <a href="{{ widget.value.url }}">{{ widget.display }}</a>
        {% endif %}
        {% if not widget.required %}
            <span class="clearable-file-input">
            <input type="checkbox" name="{{ widget.checkbox_name }}" id="{{ widget.checkbox_id }}" />
            <label for="{{ widget.checkbox_id }}">{{ widget.clear_checkbox_label }}</label></span>
        {% endif %}
        <br />
        {{ widget.input_text }}:
{% endif %}

<input type="{{ widget.type }}" name="{{ widget.name }}" {% include "django/forms/widgets/attrs.html" %} />

{% if widget.is_initial %}</p>{% endif %}
    