{% if widget.is_initial %}
    {{ widget.initial_text }}:
    {% if widget.value %}
        <a href="{{ widget.value.url }}">{{ widget.display }}</a>
    {% endif %}
    {% if not widget.required %}
        <input type="checkbox" name="{{ widget.checkbox_name }}" id="{{ widget.checkbox_id }}" />
        <label for="{{ widget.checkbox_id }}">{{ widget.clear_checkbox_label }}</label>
    {% endif %}
    <br />
    {{ widget.input_text }}:
{% endif %}
<input type="{{ widget.type }}" name="{{ widget.name }}" {% include "django/forms/widgets/attrs.html" %} />
